==> ideaIC-2017.2.6-sources.jar: com/android/tools/idea/gradle/structure/daemon/analysis/PsJavaModuleAnalyzer.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.structure.daemon.analysis;

import com.android.tools.idea.gradle.structure.configurables.PsContext;
import com.android.tools.idea.gradle.structure.model.PsIssueCollection;
import com.android.tools.idea.gradle.structure.model.PsLibraryDependency;
import com.android.tools.idea.gradle.structure.model.PsModulePath;
import com.android.tools.idea.gradle.structure.model.java.PsJavaModule;
import org.jetbrains.annotations.NotNull;

public class PsJavaModuleAnalyzer extends PsModuleAnalyzer<PsJavaModule> {
  public PsJavaModuleAnalyzer(@NotNull PsContext context) {
    super(context);
  }

  @Override
  protected void doAnalyze(@NotNull PsJavaModule module, @NotNull PsIssueCollection issueCollection) {
    PsModulePath modulePath = new PsModulePath(module);
    module.forEachDependency(dependency -> {
      if (dependency instanceof PsLibraryDependency && dependency.isDeclared()) {
        PsLibraryDependency libraryDependency = (PsLibraryDependency)dependency;
        analyzeDeclaredDependency(libraryDependency, modulePath, issueCollection);
      }
    });
  }

  @Override
  @NotNull
  public Class<PsJavaModule> getSupportedModelType() {
    return PsJavaModule.class;
  }
}

==> ideaIC-2018.3.3-sources.jar: com/android/tools/idea/gradle/structure/daemon/analysis/PsJavaModuleAnalyzer.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.structure.daemon.analysis;

import com.android.tools.idea.gradle.structure.configurables.PsContext;
import com.android.tools.idea.gradle.structure.model.PsIssueCollection;
import com.android.tools.idea.gradle.structure.model.PsLibraryDependency;
import com.android.tools.idea.gradle.structure.model.PsModulePath;
import com.android.tools.idea.gradle.structure.model.java.PsJavaModule;
import org.jetbrains.annotations.NotNull;

public class PsJavaModuleAnalyzer extends PsModuleAnalyzer<PsJavaModule> {
  public PsJavaModuleAnalyzer(@NotNull PsContext context) {
    super(context);
  }

  @Override
  protected void doAnalyze(@NotNull PsJavaModule module, @NotNull PsIssueCollection issueCollection) {
    PsModulePath modulePath = new PsModulePath(module);
    module.forEachDependency(dependency -> {
      if (dependency instanceof PsLibraryDependency && dependency.isDeclared()) {
        PsLibraryDependency libraryDependency = (PsLibraryDependency)dependency;
        analyzeDeclaredDependency(libraryDependency, issueCollection);
      }
    });
  }

  @Override
  @NotNull
  public Class<PsJavaModule> getSupportedModelType() {
    return PsJavaModule.class;
  }
}
